OrderAny

Enum OrderAny 

pub enum OrderAny {
    Limit(LimitOrder),
    LimitIfTouched(LimitIfTouchedOrder),
    Market(MarketOrder),
    MarketIfTouched(MarketIfTouchedOrder),
    MarketToLimit(MarketToLimitOrder),
    StopLimit(StopLimitOrder),
    StopMarket(StopMarketOrder),
    TrailingStopLimit(TrailingStopLimitOrder),
    TrailingStopMarket(TrailingStopMarketOrder),
}

Variants



Limit(LimitOrder)



LimitIfTouched(LimitIfTouchedOrder)



Market(MarketOrder)



MarketIfTouched(MarketIfTouchedOrder)



MarketToLimit(MarketToLimitOrder)



StopLimit(StopLimitOrder)



StopMarket(StopMarketOrder)



TrailingStopLimit(TrailingStopLimitOrder)



TrailingStopMarket(TrailingStopMarketOrder)

Implementations

Source

impl OrderAny

pub fn from_events(events: Vec<OrderEventAny>) -> Result<Self, OrderReplayError>

Creates a new OrderAny instance from the given events.

Errors

Returns an error if:

  • The events is empty.
  • The first event is not OrderInitialized.
  • The initialization event violates an order invariant (e.g. missing required price/trigger fields, invalid quantity, invalid TIF/expire combo).
  • Any subsequent event has an invalid state transition when applied to the order.
pub fn init_event(&self) -> &OrderInitialized

Returns a reference to the crate::events::OrderInitialized event.

This is always the first event in the order’s event list (invariant).

Panics

Panics if the first event is not OrderInitialized (violates invariant).

pub fn set_order_list_id(&mut self, id: OrderListId)

Assigns the order to the list identified by id.

Panics

Panics if the order has no events or its first event is not OrderInitialized.