pub enum OrderReplayError {
EmptyInput,
WrongFirstEvent,
InvalidInitialization {
source: OrderError,
},
ApplyFailed {
source: OrderError,
},
}Expand description
Error returned when OrderAny::from_events cannot replay order events.
Variants
EmptyInput
No events were supplied.
WrongFirstEvent
The first event was not an initialization event.
InvalidInitialization
The initialization event could not be converted into an order.
Fields

source: OrderErrorThe source order conversion error.
ApplyFailed
A later event could not be applied to the initialized order.
Fields

source: OrderErrorThe source event application error.